# Graphene-ML Example

This example demonstrates how to use `mlsolve` to perform a geometry optimization on a graphene structure with a defect using the MACE model.

## Running the Example

To run this example, execute the following command:

    mlsolve -i ml_input.py -g graphene4x4withdefect.cif

